#
# spec file for package dmapi
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define lname	libdm0
Name:           dmapi
Version:        2.2.12
Release:        2.3
Summary:        Data Management API Runtime Environment
License:        GPL-2.0+
Group:          Development/Libraries/C and C++
Url:            http://oss.sgi.com/projects/xfs/
Source0:        ftp://oss.sgi.com/projects/xfs/cmd_tars/dmapi-%{version}.tar.gz
Source1:        ftp://oss.sgi.com/projects/xfs/cmd_tars/dmapi-%{version}.tar.gz.sig
Source2:        %{name}.keyring
Source3:        baselibs.conf
Patch0:         dmapi-docdir.diff
Patch1:         no-getdents-aarch64.diff
Patch2:         dmapi-add-missing-includes-to-handle2path.patch
BuildRequires:  e2fsprogs-devel
BuildRequires:  xfsprogs-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This package contains files required by system software using the Data
Management API. (DMAPI).  This is used to implement the interface
defined in the X/Open document:  Systems Management: Data Storage
Management (XDSM) API dated February 1997.  This interface is
implemented by the libdm library.

%package -n %{lname}
Summary:        Data Management API Runtime Environment
Group:          Development/Libraries/C and C++
Obsoletes:      dmapi < %{version}-%{release}
Provides:       dmapi = %{version}-%{release}

%description -n %{lname}
This package contains files required by system software using the Data
Management API. (DMAPI).  This is used to implement the interface
defined in the X/Open document:  Systems Management: Data Storage
Management (XDSM) API dated February 1997.  This interface is
implemented by the libdm library.

%package      devel
Summary:        DMAPI Libraries and Header Files
Group:          Development/Libraries/C and C++
Requires:       %{lname} = %{version}

%description devel
The dmapi-devel package contains the libraries and header files needed
to develop programs which make use of the Data Management API (DMAPI).
If you install dmapi-devel, you will also want to install the dmapi
(runtime) package and the xfsprogs-devel package.

%prep
%setup -q
%patch0
%patch1
%patch2 -p1

%build
export LCFLAGS="%{optflags}"
# Upstream: devel files (libdm.la) into libexecdir, what gives?
%configure --libdir=/%{_lib} --libexecdir=%{_libdir}
make %{?_smp_mflags}

%install
export DIST_ROOT="$RPM_BUILD_ROOT"
%{_bindir}/make install
%{_bindir}/make install-dev
# remove devel stuff from /lib
rm %{buildroot}/%{_lib}/libdm.{so,a,la}
rm %{buildroot}/%{_libdir}/libdm.so
pushd %{buildroot}%{_libdir}
	ls ../../%{_lib}/libdm.so.[0-9]
	ln -s ../../%{_lib}/libdm.so.[0-9] libdm.so
popd
mv "%{buildroot}/%{_defaultdocdir}/%{name}" "%{buildroot}/%{_defaultdocdir}/%{lname}";
find %{buildroot}

%post -n %{lname} -p /sbin/ldconfig

%postun -n %{lname} -p /sbin/ldconfig

%files -n %{lname}
%defattr(-,root,root,755)
/%{_lib}/libdm.so.*
%doc %{_defaultdocdir}/%{lname}

%files devel
%defattr(-,root,root,755)
%{_includedir}/xfs
%{_libdir}/libdm.a
%{_libdir}/libdm.so
%{_libdir}/libdm.la
%{_mandir}/man3/*

%changelog
* Thu Nov 19 2015 jeffm@suse.com
- Added dmapi-add-missing-includes-to-handle2path.patch to fix
  build failures introduced when dependency xfsprogs-devel was
  updated to 4.2.0.
* Wed Jun  3 2015 mpluskal@suse.com
- Use url for download
- Add gpg signature
- Add baselibs.conf as source
- Cleanup spec file with spec-cleaner
* Mon Feb  3 2014 dmueller@suse.com
- update to 2.2.12:
  * Updated the release.sh script to work with newer git.
  * Various build related fixes, thanks to Theodore Ts'o,
    Mike Frysinger, and Jan Engelhardt
- add no-getdents-aarch64.diff: Fix build for aarch64
* Sun Sep 18 2011 jengelh@medozas.de
- Implement shlib policy (libdm0)
- Remove redundant tags/sections from specfile
  (cf. packaging guidelines)
- Use %%_smp_mflags for parallel build
* Wed Feb  3 2010 mmarek@suse.cz
- use the distributed configure and Makefile.in, recreating them
  with newer autotools fails.
* Tue Jan 26 2010 mmarek@suse.cz
- updated to 2.2.10
  * Various buildsystem fixes
* Fri Jun 22 2007 mmarek@suse.cz
- updated to 2.2.8
  * Fix a problem in get_mnt() called by dm_handle_to_path()
    The "dmi" mount option was not considered.
  * Fix issues with makedepend on libtool libraries.
  * Makefile dependency fixes
- specfile cleanup
* Wed Jan 24 2007 mmarek@suse.cz
- use $RPM_OPT_FLAGS
* Thu Jul 27 2006 mjancar@suse.cz
- update to 2.2.5
  * Debian packaging updates (debmake out, debhelper in)
  * Fix Debian build packaging dependency.
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Mon Jan 16 2006 mjancar@suse.cz
- update to 2.2.3
* Sun Aug 21 2005 ro@suse.de
- no .a/.la files in /
* Mon Feb  7 2005 mjancar@suse.cz
- update to 2.2.1
* Fri Aug  6 2004 mjancar@suse.cz
- update to 2.2.0
* Thu Feb 26 2004 mjancar@suse.cz
- update to 2.1.0
* Sun Jan 11 2004 adrian@suse.de
- build as user
* Fri Jun 20 2003 ja@suse.cz
- Upgrade to 2.0.8.
* Mon Jun 16 2003 ja@suse.cz
- File list fixed for dmapi-devel.
* Tue Apr 29 2003 jderfina@suse.cz
- update to version 2.0.7
* Tue Aug 20 2002 ro@suse.de
- fix links in devel package
  (broken for this case where PKG_DEVLIB_DIR == PKG_LIB_DIR)
* Tue Aug 20 2002 mge@suse.de
- update to 2.0.5
* Thu May  9 2002 tcrhak@suse.cz
- fixed to build with lib64
* Mon Feb 25 2002 ro@suse.de
- update to 2.0.0
* Tue Aug 21 2001 adostal@suse.cz
- split dmapi-0.1.1 from package xfsprogs
- use DESTDIR from %%install (...destdir.patch)
- create  ...dirs.patch
